@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package YAML::PP;
 
-our $VERSION = '0.031_002'; # TRIAL VERSION
+our $VERSION = '0.033_001'; # TRIAL VERSION
 
 use YAML::PP::Schema;
 use YAML::PP::Schema::JSON;
@@ -543,10 +543,22 @@ Values: C<perl> (currently default), C<JSON::PP>, C<boolean>
 
 This option is for loading and dumping.
 
-Note that when dumping, only the chosen boolean style will be recognized.
-So if you choose C<JSON::PP>, C<boolean> objects will not be recognized
-as booleans and will be dumped as ordinary objects (if you enable the
-Perl schema).
+You can also specify more than one class, comma separated.
+This is important for dumping.
+
+Examples:
+
+    boolean => 'JSON::PP,boolean'
+    Booleans will be loaded as JSON::PP::Booleans, but when dumping, also
+    'boolean' objects will be recognized
+
+    boolean => 'JSON::PP,*'
+    Booleans will be loaded as JSON::PP::Booleans, but when dumping, all
+    currently supported boolean classes will be recognized
+
+    boolean => '*'
+    Booleans will be loaded as perl booleans, but when dumping, all
+    currently supported boolean classes will be recognized
 
 =item schema
 
@@ -706,7 +718,7 @@ This option is for loading and dumping.
 
 Preserving scalar styles is still experimental.
 
-    use YAML::PP::Common qw/ PRESERVE_ORDER PRESERVE_SCALAR_STYLE /;
+    use YAML::PP::Common qw/ :PRESERVE /;
 
     # Preserve the order of hash keys
     my $yp = YAML::PP->new( preserve => PRESERVE_ORDER );
