@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package YAML::PP::Constructor;
 
-our $VERSION = '0.031_002'; # TRIAL VERSION
+our $VERSION = '0.033_001'; # TRIAL VERSION
 
 use YAML::PP;
 use YAML::PP::Common qw/
@@ -139,7 +139,7 @@ sub mapping_start_event {
     my $preserve_style = $self->preserve_flow_style;
     my $preserve_alias = $self->preserve_alias;
     if (($preserve_order or $preserve_style or $preserve_alias) and not tied(%$data)) {
-        tie %$data, 'YAML::PP::Preserve::Hash';
+        tie %$data, 'YAML::PP::Preserve::Hash', %$data;
     }
     if ($preserve_style) {
         my $t = tied %$data;
