@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package YAML::PP::Dumper;
 
-our $VERSION = '0.031_002'; # TRIAL VERSION
+our $VERSION = '0.033_001'; # TRIAL VERSION
 
 use Scalar::Util qw/ blessed refaddr reftype /;
 use YAML::PP;
@@ -253,7 +253,8 @@ sub check_references {
     my $reftype = reftype $doc or return;
     my $seen = $self->{seen};
     # check which references are used more than once
-    if ($reftype eq 'SCALAR' and ref $doc eq $self->representer->schema->bool_class) {
+    if ($reftype eq 'SCALAR' and
+        grep { ref $doc eq $_ } @{ $self->representer->schema->bool_class || [] }) {
         # JSON::PP and boolean.pm always return the same reference for booleans
         # Avoid printing *aliases in those case
         if (ref $doc eq 'boolean' or ref $doc eq 'JSON::PP::Boolean') {
