@@ -4,7 +4,7 @@ package YAML::PP::Schema;
 use B;
 use Module::Load qw//;
 
-our $VERSION = '0.031_002'; # TRIAL VERSION
+our $VERSION = '0.033_001'; # TRIAL VERSION
 
 use YAML::PP::Common qw/ YAML_PLAIN_SCALAR_STYLE /;
 
@@ -21,25 +21,32 @@ sub new {
     }
     my $true;
     my $false;
-    my $bool_class = '';
-    if ($bool eq 'JSON::PP') {
-        require JSON::PP;
-        $true = \&bool_jsonpp_true;
-        $false = \&bool_jsonpp_false;
-        $bool_class = 'JSON::PP::Boolean';
-    }
-    elsif ($bool eq 'boolean') {
-        require boolean;
-        $true = \&bool_booleanpm_true;
-        $false = \&bool_booleanpm_false;
-        $bool_class = 'boolean';
-    }
-    elsif ($bool eq 'perl') {
-        $true = \&bool_perl_true;
-        $false = \&bool_perl_false;
-    }
-    else {
-        die "Invalid value for 'boolean': '$bool'. Allowed: ('perl', 'boolean', 'JSON::PP')";
+    my @bool_class;
+    my @bools = split m/,/, $bool;
+    for my $b (@bools) {
+        if ($b eq '*') {
+            push @bool_class, ('boolean', 'JSON::PP::Boolean');
+            last;
+        }
+        elsif ($b eq 'JSON::PP') {
+            require JSON::PP;
+            $true ||= \&bool_jsonpp_true;
+            $false ||= \&bool_jsonpp_false;
+            push @bool_class, 'JSON::PP::Boolean';
+        }
+        elsif ($b eq 'boolean') {
+            require boolean;
+            $true ||= \&bool_booleanpm_true;
+            $false ||= \&bool_booleanpm_false;
+            push @bool_class, 'boolean';
+        }
+        elsif ($b eq 'perl') {
+            $true ||= \&bool_perl_true;
+            $false ||= \&bool_perl_false;
+        }
+        else {
+            die "Invalid value for 'boolean': '$b'. Allowed: ('perl', 'boolean', 'JSON::PP')";
+        }
     }
 
     my %representers = (
@@ -62,7 +69,7 @@ sub new {
         representers => \%representers,
         true => $true,
         false => $false,
-        bool_class => $bool_class,
+        bool_class => \@bool_class,
     }, $class;
     return $self;
 }
@@ -72,7 +79,7 @@ sub representers { return $_[0]->{representers} }
 
 sub true { return $_[0]->{true} }
 sub false { return $_[0]->{false} }
-sub bool_class { return $_[0]->{bool_class} }
+sub bool_class { return @{ $_[0]->{bool_class} } ? $_[0]->{bool_class} : undef }
 sub yaml_version { return $_[0]->{yaml_version} }
 
 my %LOADED_SCHEMA = (
